@@ -82,7 +82,10 @@ def best_two_indice_rebalancing(price_data=None, target_vol = None, rebalancing_
     for me_consti in constituents:
         return_underlying = f'returns_{me_consti}'
         return_underlyings.append(return_underlying)
-        price_data[return_underlying] = price_data[me_consti].pct_change()
+        try:
+            price_data[return_underlying] = price_data[me_consti].pct_change()
+        except ZeroDivisionError as e:
+            print(e)
 
         past_perf_underlying = f'past_perf_{me_consti}'
         past_perf_underlyings.append(past_perf_underlying)
@@ -102,7 +105,6 @@ def best_two_indice_rebalancing(price_data=None, target_vol = None, rebalancing_
     print(f'date range before filtering {min(price_data.index)} {max(price_data.index)}')
     price_data = price_data.loc[price_data.index >= inception_date, :]
     print(f'date range after filtering {min(price_data.index)} {max(price_data.index)}')
-    assert inception_date in price_data.index
 
 
     date_utility.add_rebalancing_datepart(price_data, 'Date', rebalancing_method = rebalancing_method, last=last)
