@@ -706,7 +706,7 @@ class RealTimeSignalEnsemblingParalleLauncher():
         local_rolling_np = local_signal_df.values[starting_train:stopping_train, :]
 
         y_train_true = full_y_true[starting_train:stopping_train]
-        y_train_pred = np.mean(local_rolling_np, axis=1)
+        y_train_pred = np.nanmean(local_rolling_np, axis=1)
         print('finding the best minute discretization')
         print(str(len(y_train_true)))
         print(str(len(y_train_pred)))
@@ -752,7 +752,7 @@ class RealTimeSignalEnsemblingParalleLauncher():
         local_rolling_np = local_signal_df.values[starting_train:stopping_train, :]
 
         y_train_true = full_y_true[starting_train:stopping_train]
-        y_train_pred = np.mean(local_rolling_np, axis=1)
+        y_train_pred = np.nanmean(local_rolling_np, axis=1)
         print('finding the best day discretization')
         print(str(len(y_train_true)))
         print(str(len(y_train_pred)))
